//
//	vvco.h
//
//	Created on: Jan 23, 2021
//      Author: vagner
//

#pragma once

#include <string>
#include <vector>

#include <jsoncpp/json/json.h>

namespace vserial
{

    //  bytesize
    enum class bytesize_t
    {
        fivebits = 5,
        sixbits = 6,
        sevenbits = 7,
        eightbits = 8
        , bits_err = -1
    };

    //  parity
    enum class  parity_t
    {
        parity_none = 0,
        parity_odd = 1,
        parity_even = 2,
        parity_mark = 3,
        parity_space = 4
        , parity_err = -1
    };

    //  ctopbits
    enum class  stopbits_t
    {
        stopbits_one = 1,
        stopbits_two = 2,
        stopbits_one_point_five
        , stopbits_err = -1
    };

    //  flowcontrol
    enum class flowcontrol_t
    {
        flowcontrol_none = 0,
        flowcontrol_software,
        flowcontrol_hardware
    };

    //-----------------------------------------------------------------------------
    //  настройки ком-порта
    class vco
    {
    public:

        //  is_empty
        bool is_empty;

        //   rs-порт.
        std::string port;

        //  Скорость.
        int baud_rate;

        //  количество бит в байте
        bytesize_t bytesize;

        //  контроль четности
        parity_t parity;

        //  количество стоп-бит
        stopbits_t stopbits;

        //  управление обменом
        flowcontrol_t flowcontrol;

        //  def ctor
        vco ( );

        //  ctor
        vco ( const std::string& port, const int baude_rate, const std::string& co );

        //  ctor
        vco ( Json::Value& node );

        //  анализ
        void parse ( const std::string& co );

        //  валидировать
        bool validate ( );

        //  сравнить настройки
        bool compare ( const vco& co );

    };

} /* namespace vserial */
